[ros-diffs] [ion] 22675: - Implement, export and NDKize: DbgUiGetThreadDebugObject, DbgUiDebugActiveProcess, DbgUiStopDebugging, NtSetInformationDebugObject. - Make CheckRemoteDebuggerPresent fail if no process was specified. - Implement DebugActiveProcess, DebugActiveProcessStop, DebugBreakProcess, DebugSetProcessKillOnExit. - Add *.vcproj to ignore lists.

ion at svn.reactos.org ion at svn.reactos.org
Wed Jun 28 19:02:38 CEST 2006


Author: ion
Date: Wed Jun 28 21:02:37 2006
New Revision: 22675

URL: http://svn.reactos.org/svn/reactos?rev=22675&view=rev
Log:
- Implement, export and NDKize: DbgUiGetThreadDebugObject, DbgUiDebugActiveProcess, DbgUiStopDebugging, NtSetInformationDebugObject.
- Make CheckRemoteDebuggerPresent fail if no process was specified.
- Implement DebugActiveProcess, DebugActiveProcessStop, DebugBreakProcess, DebugSetProcessKillOnExit.
- Add *.vcproj to ignore lists.

Removed:
    trunk/reactos/dll/win32/kernel32/debug/break.c
Modified:
    trunk/reactos/dll/3rdparty/freetype/   (props changed)
    trunk/reactos/dll/3rdparty/mesa32/   (props changed)
    trunk/reactos/dll/cpl/access/   (props changed)
    trunk/reactos/dll/cpl/appwiz/   (props changed)
    trunk/reactos/dll/cpl/desk/   (props changed)
    trunk/reactos/dll/cpl/hdwwiz/   (props changed)
    trunk/reactos/dll/cpl/intl/   (props changed)
    trunk/reactos/dll/cpl/intl_new/   (props changed)
    trunk/reactos/dll/cpl/main/   (props changed)
    trunk/reactos/dll/cpl/mmsys/   (props changed)
    trunk/reactos/dll/cpl/ncpa/   (props changed)
    trunk/reactos/dll/cpl/powercfg/   (props changed)
    trunk/reactos/dll/cpl/sysdm/   (props changed)
    trunk/reactos/dll/cpl/timedate/   (props changed)
    trunk/reactos/dll/directx/d3d8thk/   (props changed)
    trunk/reactos/dll/directx/ddraw/   (props changed)
    trunk/reactos/dll/directx/devenum/   (props changed)
    trunk/reactos/dll/directx/dinput/   (props changed)
    trunk/reactos/dll/directx/dinput8/   (props changed)
    trunk/reactos/dll/directx/dplay/   (props changed)
    trunk/reactos/dll/directx/dplayx/   (props changed)
    trunk/reactos/dll/directx/dsound/   (props changed)
    trunk/reactos/dll/directx/dxdiagn/   (props changed)
    trunk/reactos/dll/keyboard/kbdbe/   (props changed)
    trunk/reactos/dll/keyboard/kbdda/   (props changed)
    trunk/reactos/dll/keyboard/kbddv/   (props changed)
    trunk/reactos/dll/keyboard/kbdes/   (props changed)
    trunk/reactos/dll/keyboard/kbdfr/   (props changed)
    trunk/reactos/dll/keyboard/kbdgr/   (props changed)
    trunk/reactos/dll/keyboard/kbdhe/   (props changed)
    trunk/reactos/dll/keyboard/kbdheb/   (props changed)
    trunk/reactos/dll/keyboard/kbdhu/   (props changed)
    trunk/reactos/dll/keyboard/kbdpo/   (props changed)
    trunk/reactos/dll/keyboard/kbdru/   (props changed)
    trunk/reactos/dll/keyboard/kbdse/   (props changed)
    trunk/reactos/dll/keyboard/kbdsg/   (props changed)
    trunk/reactos/dll/keyboard/kbdsk/   (props changed)
    trunk/reactos/dll/keyboard/kbduk/   (props changed)
    trunk/reactos/dll/keyboard/kbdur/   (props changed)
    trunk/reactos/dll/keyboard/kbdus/   (props changed)
    trunk/reactos/dll/ntdll/   (props changed)
    trunk/reactos/dll/ntdll/dbg/dbgui.c   (contents, props changed)
    trunk/reactos/dll/ntdll/def/ntdll.def
    trunk/reactos/dll/win32/acledit/   (props changed)
    trunk/reactos/dll/win32/aclui/   (props changed)
    trunk/reactos/dll/win32/advapi32/   (props changed)
    trunk/reactos/dll/win32/advpack/   (props changed)
    trunk/reactos/dll/win32/authz/   (props changed)
    trunk/reactos/dll/win32/avifil32/   (props changed)
    trunk/reactos/dll/win32/cabinet/   (props changed)
    trunk/reactos/dll/win32/cards/   (props changed)
    trunk/reactos/dll/win32/cfgmgr32/   (props changed)
    trunk/reactos/dll/win32/comctl32/   (props changed)
    trunk/reactos/dll/win32/comdlg32/   (props changed)
    trunk/reactos/dll/win32/crtdll/   (props changed)
    trunk/reactos/dll/win32/crypt32/   (props changed)
    trunk/reactos/dll/win32/cryptdll/   (props changed)
    trunk/reactos/dll/win32/dbghelp/   (props changed)
    trunk/reactos/dll/win32/devmgr/   (props changed)
    trunk/reactos/dll/win32/dhcpcsvc/   (props changed)
    trunk/reactos/dll/win32/dnsapi/   (props changed)
    trunk/reactos/dll/win32/fmifs/   (props changed)
    trunk/reactos/dll/win32/gdi32/   (props changed)
    trunk/reactos/dll/win32/gdiplus/   (props changed)
    trunk/reactos/dll/win32/glu32/   (props changed)
    trunk/reactos/dll/win32/hid/   (props changed)
    trunk/reactos/dll/win32/icmp/   (props changed)
    trunk/reactos/dll/win32/imagehlp/   (props changed)
    trunk/reactos/dll/win32/imm32/   (props changed)
    trunk/reactos/dll/win32/iphlpapi/   (props changed)
    trunk/reactos/dll/win32/kernel32/   (props changed)
    trunk/reactos/dll/win32/kernel32/debug/debugger.c
    trunk/reactos/dll/win32/kernel32/include/kernel32.h
    trunk/reactos/dll/win32/kernel32/kernel32.rbuild
    trunk/reactos/dll/win32/kernel32/misc/console.c
    trunk/reactos/dll/win32/kernel32/tests/   (props changed)
    trunk/reactos/dll/win32/lsasrv/   (props changed)
    trunk/reactos/dll/win32/lzexpand/   (props changed)
    trunk/reactos/dll/win32/mapi32/   (props changed)
    trunk/reactos/dll/win32/mmdrv/   (props changed)
    trunk/reactos/dll/win32/mpr/   (props changed)
    trunk/reactos/dll/win32/msacm/   (props changed)
    trunk/reactos/dll/win32/msafd/   (props changed)
    trunk/reactos/dll/win32/msgina/   (props changed)
    trunk/reactos/dll/win32/msi/   (props changed)
    trunk/reactos/dll/win32/msimg32/   (props changed)
    trunk/reactos/dll/win32/msvcrt/   (props changed)
    trunk/reactos/dll/win32/msvcrt20/   (props changed)
    trunk/reactos/dll/win32/msvideo/   (props changed)
    trunk/reactos/dll/win32/mswsock/   (props changed)
    trunk/reactos/dll/win32/netapi32/   (props changed)
    trunk/reactos/dll/win32/netcfgx/   (props changed)
    trunk/reactos/dll/win32/newdev/   (props changed)
    trunk/reactos/dll/win32/ntmarta/   (props changed)
    trunk/reactos/dll/win32/objsel/   (props changed)
    trunk/reactos/dll/win32/ole32/   (props changed)
    trunk/reactos/dll/win32/oleacc/   (props changed)
    trunk/reactos/dll/win32/oleaut32/   (props changed)
    trunk/reactos/dll/win32/oledlg/   (props changed)
    trunk/reactos/dll/win32/olepro32/   (props changed)
    trunk/reactos/dll/win32/opengl32/   (props changed)
    trunk/reactos/dll/win32/powrprof/   (props changed)
    trunk/reactos/dll/win32/psapi/   (props changed)
    trunk/reactos/dll/win32/riched20/   (props changed)
    trunk/reactos/dll/win32/richedit/   (props changed)
    trunk/reactos/dll/win32/rpcrt4/   (props changed)
    trunk/reactos/dll/win32/samlib/   (props changed)
    trunk/reactos/dll/win32/samsrv/   (props changed)
    trunk/reactos/dll/win32/secur32/   (props changed)
    trunk/reactos/dll/win32/security/   (props changed)
    trunk/reactos/dll/win32/serialui/   (props changed)
    trunk/reactos/dll/win32/setupapi/   (props changed)
    trunk/reactos/dll/win32/shdocvw/   (props changed)
    trunk/reactos/dll/win32/shell32/   (props changed)
    trunk/reactos/dll/win32/shellext/slayer/   (props changed)
    trunk/reactos/dll/win32/shfolder/   (props changed)
    trunk/reactos/dll/win32/shlwapi/   (props changed)
    trunk/reactos/dll/win32/smdll/   (props changed)
    trunk/reactos/dll/win32/snmpapi/   (props changed)
    trunk/reactos/dll/win32/syssetup/   (props changed)
    trunk/reactos/dll/win32/twain/   (props changed)
    trunk/reactos/dll/win32/urlmon/   (props changed)
    trunk/reactos/dll/win32/user32/   (props changed)
    trunk/reactos/dll/win32/userenv/   (props changed)
    trunk/reactos/dll/win32/uxtheme/   (props changed)
    trunk/reactos/dll/win32/vdmdbg/   (props changed)
    trunk/reactos/dll/win32/version/   (props changed)
    trunk/reactos/dll/win32/wininet/   (props changed)
    trunk/reactos/dll/win32/winmm/   (props changed)
    trunk/reactos/dll/win32/winmm/midimap/   (props changed)
    trunk/reactos/dll/win32/winmm/wavemap/   (props changed)
    trunk/reactos/dll/win32/winspool/   (props changed)
    trunk/reactos/dll/win32/wintrust/   (props changed)
    trunk/reactos/dll/win32/ws2_32/   (props changed)
    trunk/reactos/dll/win32/ws2help/   (props changed)
    trunk/reactos/dll/win32/wshirda/   (props changed)
    trunk/reactos/dll/win32/wsock32/   (props changed)
    trunk/reactos/include/ndk/dbgkfuncs.h
    trunk/reactos/include/ndk/umfuncs.h
    trunk/reactos/include/reactos/idl/   (props changed)
    trunk/reactos/ntoskrnl/   (props changed)
    trunk/reactos/tools/nci/sysfuncs.lst

Propchange: trunk/reactos/dll/3rdparty/freetype/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -8,3 +8,4 @@
 doxy-doc
 freetype.coff
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/3rdparty/mesa32/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -1,1 +1,2 @@
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/cpl/access/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -12,3 +12,4 @@
 Debug
 Release
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/cpl/appwiz/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -12,3 +12,4 @@
 Debug
 Release
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/cpl/desk/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -12,3 +12,4 @@
 Debug
 Release
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/cpl/hdwwiz/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -1,1 +1,2 @@
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/cpl/intl/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -7,3 +7,4 @@
 *.map
 *.tmp
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/cpl/intl_new/
------------------------------------------------------------------------------
--- svn:ignore (added)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -1,0 +1,1 @@
+*.vcproj

Propchange: trunk/reactos/dll/cpl/main/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -7,3 +7,4 @@
 *.map
 *.tmp
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/cpl/mmsys/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -7,3 +7,4 @@
 *.map
 *.tmp
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/cpl/ncpa/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -14,3 +14,4 @@
 Debug
 Release
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/cpl/powercfg/
------------------------------------------------------------------------------
--- svn:ignore (added)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -1,0 +1,1 @@
+*.vcproj

Propchange: trunk/reactos/dll/cpl/sysdm/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -7,3 +7,4 @@
 *.map
 *.tmp
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/cpl/timedate/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -7,3 +7,4 @@
 *.map
 *.tmp
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/directx/d3d8thk/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -9,3 +9,4 @@
 *.tmp
 *.map
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/directx/ddraw/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -1,1 +1,2 @@
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/directx/devenum/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -9,3 +9,4 @@
 devenum.spec.def
 devenum.stubs.c
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/directx/dinput/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -12,3 +12,4 @@
 *.bmp
 *.cur
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/directx/dinput8/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -12,3 +12,4 @@
 *.bmp
 *.cur
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/directx/dplay/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -1,1 +1,2 @@
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/directx/dplayx/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -1,1 +1,2 @@
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/directx/dsound/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -9,3 +9,4 @@
 dsound.spec.def
 dsound.stubs.c
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/directx/dxdiagn/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -1,1 +1,2 @@
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/keyboard/kbdbe/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -1,1 +1,2 @@
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/keyboard/kbdda/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -11,3 +11,4 @@
 *.map
 *.d
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/keyboard/kbddv/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -11,3 +11,4 @@
 *.map
 *.d
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/keyboard/kbdes/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -16,3 +16,4 @@
 *.bak
 *.map
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/keyboard/kbdfr/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -10,3 +10,4 @@
 *.map
 *.d
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/keyboard/kbdgr/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -11,3 +11,4 @@
 *.map
 *.d
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/keyboard/kbdhe/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -1,1 +1,2 @@
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/keyboard/kbdheb/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -1,1 +1,2 @@
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/keyboard/kbdhu/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -1,1 +1,2 @@
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/keyboard/kbdpo/
------------------------------------------------------------------------------
--- svn:ignore (added)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -1,0 +1,1 @@
+*.vcproj

Propchange: trunk/reactos/dll/keyboard/kbdru/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -9,3 +9,4 @@
 *.map
 *.d
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/keyboard/kbdse/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -11,3 +11,4 @@
 *.map
 *.d
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/keyboard/kbdsg/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -10,3 +10,4 @@
 *.map
 *.d
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/keyboard/kbdsk/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -1,1 +1,2 @@
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/keyboard/kbduk/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -11,3 +11,4 @@
 *.map
 *.d
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/keyboard/kbdur/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -1,1 +1,2 @@
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/keyboard/kbdus/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -11,3 +11,4 @@
 *.map
 *.d
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/ntdll/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -11,3 +11,4 @@
 *.map
 doxy-doc
 GNUmakefile
+*.vcproj

Modified: trunk/reactos/dll/ntdll/dbg/dbgui.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/dll/ntdll/dbg/dbgui.c?rev=22675&r1=22674&r2=22675&view=diff
==============================================================================
--- svn:needs-lock (original)
+++ svn:needs-lock (removed)
@@ -1,1 +1,0 @@
-*

Modified: trunk/reactos/dll/ntdll/def/ntdll.def
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/dll/ntdll/def/ntdll.def?rev=22675&r1=22674&r2=22675&view=diff
==============================================================================
--- trunk/reactos/dll/ntdll/def/ntdll.def (original)
+++ trunk/reactos/dll/ntdll/def/ntdll.def Wed Jun 28 21:02:37 2006
@@ -24,10 +24,13 @@
 DbgPrint
 DbgPrintEx
 DbgPrompt at 12
+DbgUiDebugActiveProcess at 4
 DbgUiConnectToDbg at 0
 DbgUiContinue at 8
+DbgUiGetThreadDebugObject at 0
 DbgUiIssueRemoteBreakin at 4
 DbgUiRemoteBreakin at 0
+DbgUiStopDebugging at 4
 DbgUiWaitStateChange at 8
 DbgUserBreakPoint at 0
 KiRaiseUserExceptionDispatcher at 0
@@ -230,6 +233,7 @@
 NtSetEvent at 8
 NtSetHighEventPair at 4
 NtSetHighWaitLowEventPair at 4
+NtSetInformationDebugObject at 20
 NtSetInformationFile at 20
 NtSetInformationJobObject at 16
 NtSetInformationKey at 16

Propchange: trunk/reactos/dll/win32/acledit/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -7,3 +7,4 @@
 *.map
 *.tmp
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/aclui/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -8,3 +8,4 @@
 *.tmp
 *.gch
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/advapi32/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -10,3 +10,4 @@
 *.gch
 *.d
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/advpack/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -7,3 +7,4 @@
 *.map
 *.tmp
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/authz/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -8,3 +8,4 @@
 *.tmp
 *.gch
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/avifil32/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -1,1 +1,2 @@
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/cabinet/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -9,3 +9,4 @@
 cabinet.spec.def
 cabinet.stubs.c
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/cards/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -9,3 +9,4 @@
 *.tmp
 *.o
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/cfgmgr32/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -16,3 +16,4 @@
 *.bak
 *.map
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/comctl32/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -12,3 +12,4 @@
 *.spec.def
 *.stubs.c
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/comdlg32/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -13,3 +13,4 @@
 *.stubs.c
 *.ico
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/crtdll/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -8,3 +8,4 @@
 *.tmp
 *.gch
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/crypt32/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -1,1 +1,2 @@
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/cryptdll/
------------------------------------------------------------------------------
--- svn:ignore (added)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -1,0 +1,1 @@
+*.vcproj

Propchange: trunk/reactos/dll/win32/dbghelp/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -26,3 +26,4 @@
 dbghelp.spec.def
 dbghelp.stubs.c
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/devmgr/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -1,1 +1,2 @@
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/dhcpcsvc/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -1,1 +1,2 @@
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/dnsapi/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -11,3 +11,4 @@
 *.txt
 *.map
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/fmifs/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -7,3 +7,4 @@
 *.d
 *.map
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/gdi32/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -5,3 +5,4 @@
 *.a
 *.map
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/gdiplus/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -5,3 +5,4 @@
 *.a
 *.map
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/glu32/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -8,3 +8,4 @@
 *.tmp
 *.o
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/hid/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -7,3 +7,4 @@
 *.map
 *.tmp
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/icmp/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -1,1 +1,2 @@
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/imagehlp/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -11,3 +11,4 @@
 *.txt
 *.map
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/imm32/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -1,1 +1,2 @@
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/iphlpapi/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -20,3 +20,4 @@
 iphlpapi.spec.def
 iphlpapi.stubs.c
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/kernel32/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -13,3 +13,4 @@
 *.pch
 *.map
 GNUmakefile
+*.vcproj

Removed: trunk/reactos/dll/win32/kernel32/debug/break.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/dll/win32/kernel32/debug/break.c?rev=22674&view=auto
==============================================================================
--- trunk/reactos/dll/win32/kernel32/debug/break.c (original)
+++ trunk/reactos/dll/win32/kernel32/debug/break.c (removed)
@@ -1,32 +1,0 @@
-/* $Id$
- *
- * COPYRIGHT:       See COPYING in the top level directory
- * PROJECT:         ReactOS system libraries
- * FILE:            lib/kernel32/debug/debugger.c
- * PURPOSE:         DebugBreakProcess()
- * PROGRAMMER:      KJK::Hyperion <noog at libero.it>
- */
-
-/* INCLUDES ******************************************************************/
-
-#include <k32.h>
-
-/* FUNCTIONS *****************************************************************/
-
-/*
- * @implemented
- */
-WINBASEAPI BOOL WINAPI DebugBreakProcess(HANDLE Process)
-{
- NTSTATUS nErrCode = DbgUiIssueRemoteBreakin(Process);
-
- if(!NT_SUCCESS(nErrCode))
- {
-  SetLastErrorByStatus(nErrCode);
-  return FALSE;
- }
-
- return TRUE;
-}
-
-/* EOF */

Modified: trunk/reactos/dll/win32/kernel32/debug/debugger.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/dll/win32/kernel32/debug/debugger.c?rev=22675&r1=22674&r2=22675&view=diff
==============================================================================
--- trunk/reactos/dll/win32/kernel32/debug/debugger.c (original)
+++ trunk/reactos/dll/win32/kernel32/debug/debugger.c Wed Jun 28 21:02:37 2006
@@ -1,147 +1,261 @@
-/* $Id$
- *
- * COPYRIGHT:       See COPYING in the top level directory
- * PROJECT:         ReactOS system libraries
- * FILE:            lib/kernel32/debug/debugger.c
- * PURPOSE:         Win32 Debugger API
- * PROGRAMMER:      Thomas Weidenmueller
- *                  KJK::Hyperion
- */
-
-/* INCLUDES ******************************************************************/
+/*
+ * PROJECT:         ReactOS Win32 Base API
+ * LICENSE:         GPL - See COPYING in the top level directory
+ * FILE:            dll/win32/kernel32/debug/debugger.c
+ * PURPOSE:         Wrappers for the NT Debug Implementation
+ * PROGRAMMERS:     Alex Ionescu (alex.ionescu at reactos.org)
+ */
+
+/* INCLUDES *****************************************************************/
 
 #include <k32.h>
 
+#define NDEBUG
+#include "debug.h"
+
 /* FUNCTIONS *****************************************************************/
 
 /*
  * @implemented
  */
-BOOL WINAPI
-CheckRemoteDebuggerPresent (
-    HANDLE hProcess,
-    PBOOL pbDebuggerPresent
-    )
-{
-  HANDLE DebugPort;
-  NTSTATUS Status;
-
-  if (pbDebuggerPresent == NULL)
-  {
-    SetLastError(ERROR_INVALID_PARAMETER);
-    return FALSE;
-  }
-
-  Status = NtQueryInformationProcess(hProcess,
-                                     ProcessDebugPort,
-                                     (PVOID)&DebugPort,
-                                     sizeof(HANDLE),
-                                     NULL);
-  if (NT_SUCCESS(Status))
-  {
-    *pbDebuggerPresent = ((DebugPort != NULL) ? TRUE : FALSE);
-    return TRUE;
-  }
-
-  SetLastErrorByStatus(Status);
-  return FALSE;
-}
-
-
-/*
- * @implemented
- */
-BOOL WINAPI
-ContinueDebugEvent (
-    DWORD dwProcessId,
-    DWORD dwThreadId,
-    DWORD dwContinueStatus
-    )
-{
-  CLIENT_ID ClientId;
-  NTSTATUS Status;
-
-  ClientId.UniqueProcess = (HANDLE)dwProcessId;
-  ClientId.UniqueThread = (HANDLE)dwThreadId;
-
-  Status = DbgUiContinue(&ClientId, dwContinueStatus);
-  if (!NT_SUCCESS(Status))
-  {
+BOOL
+WINAPI
+CheckRemoteDebuggerPresent(IN HANDLE hProcess,
+                           OUT PBOOL pbDebuggerPresent)
+{
+    HANDLE DebugPort;
+    NTSTATUS Status;
+
+    /* Make sure we have an output and process*/
+    if (!(pbDebuggerPresent) || !(hProcess))
+    {
+        /* Fail */
+        SetLastError(ERROR_INVALID_PARAMETER);
+        return FALSE;
+    }
+
+    /* Check if the process has a debug object/port */
+    Status = NtQueryInformationProcess(hProcess,
+                                       ProcessDebugPort,
+                                       (PVOID)&DebugPort,
+                                       sizeof(HANDLE),
+                                       NULL);
+    if (NT_SUCCESS(Status))
+    {
+        /* Return the current state */
+        *pbDebuggerPresent = (DebugPort) ? TRUE : FALSE;
+        return TRUE;
+    }
+
+    /* Otherwise, fail */
     SetLastErrorByStatus(Status);
     return FALSE;
-  }
-
-  return TRUE;
-}
-
-
-/*
- * NOTE: I'm not sure if the function is complete.
- *
+}
+
+/*
+ * @implemented
+ */
+BOOL
+WINAPI
+ContinueDebugEvent(IN DWORD dwProcessId,
+                   IN DWORD dwThreadId,
+                   IN DWORD dwContinueStatus)
+{
+    CLIENT_ID ClientId;
+    NTSTATUS Status;
+
+    /* Set the Client ID */
+    ClientId.UniqueProcess = (HANDLE)dwProcessId;
+    ClientId.UniqueThread = (HANDLE)dwThreadId;
+
+    /* Continue debugging */
+    Status = DbgUiContinue(&ClientId, dwContinueStatus);
+    if (!NT_SUCCESS(Status))
+    {
+        /* Fail */
+        SetLastErrorByStatus(Status);
+        return FALSE;
+    }
+
+    /* Succes */
+    return TRUE;
+}
+
+HANDLE
+ProcessIdToHandle(IN DWORD dwProcessId)
+{
+    NTSTATUS Status;
+    OBJECT_ATTRIBUTES ObjectAttributes;
+    HANDLE Handle;
+    CLIENT_ID ClientId;
+
+    /* If we don't have a PID, look it up */
+    if (dwProcessId == 0xFFFFFFFF) dwProcessId = (DWORD)CsrGetProcessId();
+
+    /* Open a handle to the process */
+    ClientId.UniqueProcess = (HANDLE)dwProcessId;
+    InitializeObjectAttributes(&ObjectAttributes, NULL, 0, NULL, NULL);
+    Status = NtOpenProcess(&Handle,
+                           PROCESS_ALL_ACCESS,
+                           &ObjectAttributes,
+                           &ClientId);
+    if (!NT_SUCCESS(Status))
+    {
+        /* Fail */
+        SetLastErrorByStatus(Status);
+        return 0;
+    }
+
+    /* Return the handle */
+    return Handle;
+}
+
+/*
+ * @implemented
+ */
+BOOL
+WINAPI
+DebugActiveProcess(IN DWORD dwProcessId)
+{
+    NTSTATUS Status;
+    HANDLE Handle;
+
+    /* Connect to the debugger */
+    Status = DbgUiConnectToDbg();
+    if (!NT_SUCCESS(Status))
+    {
+        SetLastErrorByStatus(Status);
+        return FALSE;
+    }
+
+    /* Get the process handle */
+    Handle = ProcessIdToHandle(dwProcessId);
+    if (!Handle) return FALSE;
+
+    /* Now debug the process */
+    Status = DbgUiDebugActiveProcess(Handle);
+    if (!NT_SUCCESS(Status))
+    {
+        /* Fail */
+        SetLastErrorByStatus(Status);
+        return FALSE;
+    }
+
+    /* Success */
+    return TRUE;
+}
+
+/*
+ * @implemented
+ */
+BOOL
+WINAPI
+DebugActiveProcessStop(IN DWORD dwProcessId)
+{
+    NTSTATUS Status;
+    HANDLE Handle;
+
+    /* Get the process handle */
+    Handle = ProcessIdToHandle(dwProcessId);
+    if (!Handle) return FALSE;
+
+    /* Now stop debgging the process */
+    Status = DbgUiStopDebugging(Handle);
+    NtClose(Handle);
+
+    /* Check for failure */
+    if (!NT_SUCCESS(Status))
+    {
+        /* Fail */
+        SetLastError(ERROR_ACCESS_DENIED);
+        return FALSE;
+    }
+
+    /* Success */
+    return TRUE;
+}
+
+/*
+ * @implemented
+ */
+BOOL
+WINAPI
+DebugBreakProcess(IN HANDLE Process)
+{
+    NTSTATUS Status;
+
+    /* Send the breakin request */
+    Status = DbgUiIssueRemoteBreakin(Process);
+    if(!NT_SUCCESS(Status))
+    {
+        /* Failure */
+        SetLastErrorByStatus(Status);
+        return FALSE;
+    }
+
+    /* Success */
+    return TRUE;
+}
+
+/*
+ * @implemented
+ */
+BOOL
+WINAPI
+DebugSetProcessKillOnExit(IN BOOL KillOnExit)
+{
+    HANDLE Handle;
+    NTSTATUS Status;
+    ULONG State;
+
+    /* Get the debug object */
+    Handle = DbgUiGetThreadDebugObject();
+    if (!Handle)
+    {
+        /* Fail */
+        SetLastErrorByStatus(STATUS_INVALID_HANDLE);
+        return FALSE;
+    }
+
+    /* Now set the kill-on-exit state */
+    State = KillOnExit;
+    Status = NtSetInformationDebugObject(Handle,
+                                         DebugObjectKillProcessOnExitInformation,
+                                         &State,
+                                         sizeof(State),
+                                         NULL);
+    if (!NT_SUCCESS(Status))
+    {
+        /* Fail */
+        SetLastError(Status);
+        return FALSE;
+    }
+
+    /* Success */
+    return TRUE;
+}
+
+/*
+ * @implemented
+ */
+BOOL
+WINAPI
+IsDebuggerPresent (VOID)
+{
+    return (BOOL)NtCurrentPeb()->BeingDebugged;
+}
+
+/*
  * @unimplemented
  */
 BOOL
 WINAPI
-DebugActiveProcess(
-    DWORD dwProcessId
-    )
-{
-  SetLastError(ERROR_CALL_NOT_IMPLEMENTED);
-  return FALSE;
-}
-
-
-/*
- * @unimplemented
- */
-BOOL
-WINAPI
-DebugActiveProcessStop (
-    DWORD dwProcessId
-    )
-{
-  SetLastError(ERROR_CALL_NOT_IMPLEMENTED);
-  return FALSE;
-}
-
-
-/*
- * @unimplemented
- */
-BOOL
-WINAPI
-DebugSetProcessKillOnExit (
-    BOOL KillOnExit
-    )
-{
-  SetLastError(ERROR_CALL_NOT_IMPLEMENTED);
-  return FALSE;
-}
-
-
-/*
- * @implemented
- */
-BOOL
-WINAPI
-IsDebuggerPresent (VOID)
-{
-  return (BOOL)NtCurrentPeb()->BeingDebugged;
-}
-
-
-/*
- * @unimplemented
- */
-BOOL
-WINAPI
-WaitForDebugEvent (
-    LPDEBUG_EVENT lpDebugEvent,
-    DWORD dwMilliseconds
-    )
-{
-  SetLastError(ERROR_CALL_NOT_IMPLEMENTED);
-  return FALSE;
+WaitForDebugEvent(IN LPDEBUG_EVENT lpDebugEvent,
+                  DWORD dwMilliseconds)
+{
+    /* FIXME: TODO */
+    SetLastError(ERROR_CALL_NOT_IMPLEMENTED);
+    return FALSE;
 }
 
 /* EOF */

Modified: trunk/reactos/dll/win32/kernel32/include/kernel32.h
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/dll/win32/kernel32/include/kernel32.h?rev=22675&r1=22674&r2=22675&view=diff
==============================================================================
--- trunk/reactos/dll/win32/kernel32/include/kernel32.h (original)
+++ trunk/reactos/dll/win32/kernel32/include/kernel32.h Wed Jun 28 21:02:37 2006
@@ -62,6 +62,9 @@
 BOOL STDCALL VerifyConsoleIoHandle(HANDLE Handle);
 
 BOOL STDCALL CloseConsoleHandle(HANDLE Handle);
+
+HANDLE STDCALL
+GetConsoleInputWaitHandle (VOID);
 
 HANDLE STDCALL OpenConsoleW (LPWSTR wsName,
 			     DWORD  dwDesiredAccess,

Modified: trunk/reactos/dll/win32/kernel32/kernel32.rbuild
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/dll/win32/kernel32/kernel32.rbuild?rev=22675&r1=22674&r2=22675&view=diff
==============================================================================
--- trunk/reactos/dll/win32/kernel32/kernel32.rbuild (original)
+++ trunk/reactos/dll/win32/kernel32/kernel32.rbuild Wed Jun 28 21:02:37 2006
@@ -10,7 +10,6 @@
 	<define name="WINVER">0x502</define>
 	<pch>k32.h</pch>
 	<directory name="debug">
-		<file>break.c</file>
 		<file>debugger.c</file>
 		<file>output.c</file>
 	</directory>

Modified: trunk/reactos/dll/win32/kernel32/misc/console.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/dll/win32/kernel32/misc/console.c?rev=22675&r1=22674&r2=22675&view=diff
==============================================================================
--- trunk/reactos/dll/win32/kernel32/misc/console.c (original)
+++ trunk/reactos/dll/win32/kernel32/misc/console.c Wed Jun 28 21:02:37 2006
@@ -567,7 +567,7 @@
 /*
  * @implemented
  */
-DWORD STDCALL
+HANDLE STDCALL
 GetConsoleInputWaitHandle (VOID)
      /*
       * Undocumented
@@ -585,7 +585,7 @@
       SetLastErrorByStatus(Status);
       return 0;
     }
-  return (DWORD) Request.Data.GetConsoleInputWaitHandle.InputWaitHandle;
+  return Request.Data.GetConsoleInputWaitHandle.InputWaitHandle;
 }
 
 

Propchange: trunk/reactos/dll/win32/kernel32/tests/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -7,3 +7,4 @@
 *.a
 *.pch
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/lsasrv/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -12,3 +12,4 @@
 *.map
 *.sys
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/lzexpand/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -5,3 +5,4 @@
 *.coff
 *.map
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/mapi32/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -1,1 +1,2 @@
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/mmdrv/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -8,3 +8,4 @@
 *.tmp
 temp.exp
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/mpr/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -12,3 +12,4 @@
 *.bmp
 *.cur
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/msacm/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -10,3 +10,4 @@
 msacm32.spec.def
 msacm32.stubs.c
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/msafd/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -7,3 +7,4 @@
 *.o
 *.map
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/msgina/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -7,3 +7,4 @@
 *.map
 *.tmp
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/msi/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -12,3 +12,4 @@
 *.bmp
 *.cur
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/msimg32/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -9,3 +9,4 @@
 *.spec.def
 *.stubs.c
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/msvcrt/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -11,3 +11,4 @@
 *.map
 *.gch
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/msvcrt20/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -10,3 +10,4 @@
 *.opt
 *.map
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/msvideo/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -9,3 +9,4 @@
 msvfw32.spec.def
 msvfw32.stubs.c
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/mswsock/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -8,3 +8,4 @@
 *.tmp
 temp.exp
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/netapi32/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -1,1 +1,2 @@
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/netcfgx/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -1,2 +1,3 @@
 GNUmakefile
 *.bak
+*.vcproj

Propchange: trunk/reactos/dll/win32/newdev/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -1,1 +1,2 @@
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/ntmarta/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -8,3 +8,4 @@
 *.tmp
 *.gch
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/objsel/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -1,1 +1,2 @@
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/ole32/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -10,3 +10,4 @@
 *.spec.def
 *.stubs.c
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/oleacc/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -1,1 +1,2 @@
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/oleaut32/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -12,3 +12,4 @@
 *.bmp
 *.cur
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/oledlg/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -12,3 +12,4 @@
 *.bmp
 *.cur
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/olepro32/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -12,3 +12,4 @@
 *.bmp
 *.cur
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/opengl32/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -9,3 +9,4 @@
 *.tmp
 *.o
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/powrprof/
------------------------------------------------------------------------------
--- svn:ignore (added)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -1,0 +1,1 @@
+*.vcproj

Propchange: trunk/reactos/dll/win32/psapi/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -10,3 +10,4 @@
 *.gch
 misc
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/riched20/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -9,3 +9,4 @@
 *.spec.def
 *.stubs.c
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/richedit/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -12,3 +12,4 @@
 *.bmp
 *.cur
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/rpcrt4/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -12,3 +12,4 @@
 *.bmp
 *.cur
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/samlib/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -5,3 +5,4 @@
 *.a
 *.map
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/samsrv/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -1,1 +1,2 @@
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/secur32/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -6,3 +6,4 @@
 *.d
 *.map
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/security/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -1,1 +1,2 @@
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/serialui/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -8,3 +8,4 @@
 *.a
 *.map
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/setupapi/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -12,3 +12,4 @@
 pnp_c.c
 GNUmakefile
 *.bak
+*.vcproj

Propchange: trunk/reactos/dll/win32/shdocvw/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -12,3 +12,4 @@
 *.bmp
 *.cur
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/shell32/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -10,3 +10,4 @@
 *.stubs.c
 *.ico
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/shellext/slayer/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -8,3 +8,4 @@
 *.map
 *.tmp
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/shfolder/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -1,1 +1,2 @@
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/shlwapi/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -12,3 +12,4 @@
 *.bmp
 *.cur
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/smdll/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -12,3 +12,4 @@
 *.map
 *.sys
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/snmpapi/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -18,3 +18,4 @@
 *.tmp
 *.map
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/syssetup/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -6,3 +6,4 @@
 *.map
 *.d
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/twain/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -5,3 +5,4 @@
 *.map
 *.coff
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/urlmon/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -12,3 +12,4 @@
 *.bmp
 *.cur
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/user32/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -7,3 +7,4 @@
 *.map
 *.tmp
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/userenv/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -10,3 +10,4 @@
 *.o
 *.gch
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/uxtheme/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -10,3 +10,4 @@
 *.stubs.c
 *.ico
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/vdmdbg/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -1,1 +1,2 @@
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/version/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -6,3 +6,4 @@
 *.a
 *.d
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/wininet/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -1,1 +1,2 @@
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/winmm/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -12,3 +12,4 @@
 *.bmp
 *.cur
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/winmm/midimap/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -12,3 +12,4 @@
 *.bmp
 *.cur
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/winmm/wavemap/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -12,3 +12,4 @@
 *.bmp
 *.cur
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/winspool/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -10,3 +10,4 @@
 *.map
 *.tmp
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/wintrust/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -1,1 +1,2 @@
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/ws2_32/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -8,3 +8,4 @@
 *.tmp
 temp.exp
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/ws2help/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -18,3 +18,4 @@
 *.tmp
 *.map
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/wshirda/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -18,3 +18,4 @@
 *.tmp
 *.map
 GNUmakefile
+*.vcproj

Propchange: trunk/reactos/dll/win32/wsock32/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -8,3 +8,4 @@
 *.tmp
 temp.exp
 GNUmakefile
+*.vcproj

Modified: trunk/reactos/include/ndk/dbgkfuncs.h
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/include/ndk/dbgkfuncs.h?rev=22675&r1=22674&r2=22675&view=diff
==============================================================================
--- trunk/reactos/include/ndk/dbgkfuncs.h (original)
+++ trunk/reactos/include/ndk/dbgkfuncs.h Wed Jun 28 21:02:37 2006
@@ -23,10 +23,19 @@
 // Dependencies
 //
 #include <umtypes.h>
+#include <dbgktypes.h>
 
 //
 // Native calls
 //
+NTSYSCALLAPI
+NTSTATUS
+NTAPI
+NtDebugActiveProcess(
+    IN HANDLE Process,
+    IN HANDLE DebugObject
+);
+
 NTSYSCALLAPI
 NTSTATUS
 NTAPI
@@ -56,6 +65,33 @@
     OUT PDBGUI_WAIT_STATE_CHANGE StateChange
 );
 
+NTSYSCALLAPI
+NTSTATUS
+NTAPI
+NtRemoveProcessDebug(
+    IN HANDLE Process,
+    IN HANDLE DebugObject
+);
+
+NTSYSCALLAPI
+NTSTATUS
+NTAPI
+NtSetInformationDebugObject(
+    IN HANDLE DebugObject,
+    IN DEBUGOBJECTINFOCLASS InformationClass,
+    IN PVOID Information,
+    IN ULONG InformationLength,
+    OUT PULONG ReturnLength OPTIONAL
+);
+
+NTSYSAPI
+NTSTATUS
+NTAPI
+ZwDebugActiveProcess(
+    IN HANDLE Process,
+    IN HANDLE DebugObject
+);
+
 NTSYSAPI
 NTSTATUS
 NTAPI
@@ -78,10 +114,29 @@
 NTSYSAPI
 NTSTATUS
 NTAPI
+ZwRemoveProcessDebug(
+    IN HANDLE Process,
+    IN HANDLE DebugObject
+);
+
+NTSYSAPI
+NTSTATUS
+NTAPI
 ZwWaitForDebugEvent(
     IN HANDLE DebugObject,
     IN BOOLEAN Alertable,
     IN PLARGE_INTEGER Timeout OPTIONAL,
     OUT PDBGUI_WAIT_STATE_CHANGE StateChange
 );
+
+NTSYSAPI
+NTSTATUS
+NTAPI
+ZwSetInformationDebugObject(
+    IN HANDLE DebugObject,
+    IN DEBUGOBJECTINFOCLASS InformationClass,
+    IN PVOID Information,
+    IN ULONG InformationLength,
+    OUT PULONG ReturnLength OPTIONAL
+);
 #endif

Modified: trunk/reactos/include/ndk/umfuncs.h
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/include/ndk/umfuncs.h?rev=22675&r1=22674&r2=22675&view=diff
==============================================================================
--- trunk/reactos/include/ndk/umfuncs.h (original)
+++ trunk/reactos/include/ndk/umfuncs.h Wed Jun 28 21:02:37 2006
@@ -89,6 +89,12 @@
     struct _CSR_CAPTURE_BUFFER *CaptureBuffer
 );
 
+HANDLE
+NTAPI
+CsrGetProcessId(
+    VOID
+);
+
 NTSTATUS
 NTAPI
 CsrNewThread(VOID);
@@ -141,6 +147,18 @@
 
 NTSTATUS
 NTAPI
+DbgUiDebugActiveProcess(
+    IN HANDLE Process
+);
+
+NTSTATUS
+NTAPI
+DbgUiStopDebugging(
+    IN HANDLE Process
+);
+
+NTSTATUS
+NTAPI
 DbgUiWaitStateChange(
     IN PDBGUI_WAIT_STATE_CHANGE DbgUiWaitStateCange,
     IN PLARGE_INTEGER TimeOut
@@ -156,6 +174,12 @@
 NTAPI
 DbgUiIssueRemoteBreakin(
     IN HANDLE Process
+);
+
+HANDLE
+NTAPI
+DbgUiGetThreadDebugObject(
+    VOID
 );
 
 //

Propchange: trunk/reactos/include/reactos/idl/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -1,2 +1,3 @@
 makefile
 *.h
+*.vcproj

Propchange: trunk/reactos/ntoskrnl/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Jun 28 21:02:37 2006
@@ -14,3 +14,4 @@
 *.exe
 doxy-doc
 GNUmakefile
+*.vcproj

Modified: trunk/reactos/tools/nci/sysfuncs.lst
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/tools/nci/sysfuncs.lst?rev=22675&r1=22674&r2=22675&view=diff
==============================================================================
--- trunk/reactos/tools/nci/sysfuncs.lst (original)
+++ trunk/reactos/tools/nci/sysfuncs.lst Wed Jun 28 21:02:37 2006
@@ -42,6 +42,7 @@
 NtCreateTimer 4
 NtCreateToken 13
 NtCreateWaitablePort 5
+NtDebugActiveProcess 2
 NtDebugContinue 3
 NtDelayExecution 2
 NtDeleteAtom 1
@@ -162,6 +163,7 @@
 NtReleaseMutant 2
 NtReleaseSemaphore 3
 NtRemoveIoCompletion 5
+NtRemoveProcessDebug 2
 NtReplaceKey 3
 NtReplyPort 2
 NtReplyWaitReceivePort 4
@@ -188,6 +190,7 @@
 NtSetEvent 2
 NtSetHighEventPair 1
 NtSetHighWaitLowEventPair 1
+NtSetInformationDebugObject 5
 NtSetInformationFile 5
 NtSetInformationKey 4
 NtSetInformationJobObject 4




More information about the Ros-diffs mailing list
--- trunk/reactos/dll/ntdll/dbg/dbgui.c (original)
+++ trunk/reactos/dll/ntdll/dbg/dbgui.c Wed Jun 28 21:02:37 2006
@@ -1,9 +1,9 @@
 /*
  * COPYRIGHT:       See COPYING in the top level directory
  * PROJECT:         ReactOS kernel
  * FILE:            lib/ntdll/dbg/dbgui.c
  * PURPOSE:         User-Mode DbgUI Support
  * PROGRAMMER:      Alex Ionescu (alex at relsoft.net)
  */
 
 /* INCLUDES *****************************************************************/
@@ -135,4 +135,52 @@
     return Status;
 }
 
+/*
+ * @implemented
+ */
+HANDLE
+NTAPI
+DbgUiGetThreadDebugObject(VOID)
+{
+    /* Just return the handle from the TEB */
+    return NtCurrentTeb()->DbgSsReserved[0];
+}
+
+/*
+ * @implemented
+ */
+NTSTATUS
+NTAPI
+DbgUiDebugActiveProcess(IN HANDLE Process)
+{
+    NTSTATUS Status;
+
+    /* Tell the kernel to start debugging */
+    Status = NtDebugActiveProcess(Process, NtCurrentTeb()->DbgSsReserved[0]);
+    if (NT_SUCCESS(Status))
+    {
+        /* Now break-in the process */
+        Status = DbgUiIssueRemoteBreakin(Process);
+        if (!NT_SUCCESS(Status))
+        {
+            /* We couldn't break-in, cancel debugging */
+            DbgUiStopDebugging(Process);
+        }
+    }
+
+    /* Return status */
+    return Status;
+}
+
+/*
+ * @implemented
+ */
+NTSTATUS
+NTAPI
+DbgUiStopDebugging(IN HANDLE Process)
+{
+    /* Call the kernel to remove the debug object */
+    return NtRemoveProcessDebug(Process, NtCurrentTeb()->DbgSsReserved[0]);
+}
+
 /* EOF */

Propchange: trunk/reactos/dll/ntdll/dbg/dbgui.c
------------------------------------------------------------------------------
@@ -1,9 +1,9 @@
 /*
- * COPYRIGHT:       See COPYING in the top level directory
- * PROJECT:         ReactOS kernel
- * FILE:            lib/ntdll/dbg/dbgui.c
- * PURPOSE:         User-Mode DbgUI Support
- * PROGRAMMER:      Alex Ionescu (alex at relsoft.net)
+ * PROJECT:         ReactOS NT Layer/System API
+ * LICENSE:         GPL - See COPYING in the top level directory
+ * FILE:            dll/ntdll/dbg/dbgui.c
+ * PURPOSE:         Native Wrappers for the NT Debug Implementation
+ * PROGRAMMERS:     Alex Ionescu (alex.ionescu at reactos.org)
  */
 